==> aliyun_python_sdk_eas-0.0.6-py2.py3-none-any.whl: aliyunsdkeas/request/v20210701/ListResourceInstanceWorkerRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RoaRequest
from aliyunsdkeas.endpoint import endpoint_data

class ListResourceInstanceWorkerRequest(RoaRequest):

	def __init__(self):
		RoaRequest.__init__(self, 'eas', '2021-07-01', 'ListResourceInstanceWorker','eas')
		self.set_uri_pattern('/api/v2/resources/[ClusterId]/[ResourceId]/instance/[InstanceName]/workers')
		self.set_method('GET')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ResourceId(self): # string
		return self.get_path_params().get('ResourceId')

	def set_ResourceId(self, ResourceId):  # string
		self.add_path_param('ResourceId', ResourceId)
	def get_InstanceName(self): # string
		return self.get_path_params().get('InstanceName')

	def set_InstanceName(self, InstanceName):  # string
		self.add_path_param('InstanceName', InstanceName)
	def get_PageSize(self): # integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # integer
		self.add_query_param('PageSize', PageSize)
	def get_ClusterId(self): # string
		return self.get_path_params().get('ClusterId')

	def set_ClusterId(self, ClusterId):  # string
		self.add_path_param('ClusterId', ClusterId)
	def get_PageNumber(self): # integer
		return self.get_query_params().get('PageNumber')

	def set_PageNumber(self, PageNumber):  # integer
		self.add_query_param('PageNumber', PageNumber)

==> aliyun_python_sdk_eas-0.0.9-py2.py3-none-any.whl: aliyunsdkeas/request/v20210701/ListResourceInstanceWorkerRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RoaRequest
from aliyunsdkeas.endpoint import endpoint_data

class ListResourceInstanceWorkerRequest(RoaRequest):

	def __init__(self):
		RoaRequest.__init__(self, 'eas', '2021-07-01', 'ListResourceInstanceWorker','eas')
		self.set_uri_pattern('/api/v2/resources/[ClusterId]/[ResourceId]/instance/[InstanceName]/workers')
		self.set_method('GET')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ResourceId(self): # String
		return self.get_path_params().get('ResourceId')

	def set_ResourceId(self, ResourceId):  # String
		self.add_path_param('ResourceId', ResourceId)
	def get_InstanceName(self): # String
		return self.get_path_params().get('InstanceName')

	def set_InstanceName(self, InstanceName):  # String
		self.add_path_param('InstanceName', InstanceName)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
	def get_ClusterId(self): # String
		return self.get_path_params().get('ClusterId')

	def set_ClusterId(self, ClusterId):  # String
		self.add_path_param('ClusterId', ClusterId)
	def get_PageNumber(self): # Integer
		return self.get_query_params().get('PageNumber')

	def set_PageNumber(self, PageNumber):  # Integer
		self.add_query_param('PageNumber', PageNumber)
